package cn.rongcloud.beauty.wrapper.flutter;

import androidx.annotation.NonNull;

import java.util.HashMap;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

import cn.rongcloud.beauty.wrapper.RCBeautyIWEngine;

/** RCBeautyWrapperPlugin */
public class RCBeautyWrapperPlugin implements FlutterPlugin, MethodCallHandler {

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "cn.rongcloud.beauty.flutter/engine");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    switch (call.method) {
      case "setBeautyOptions":
        setBeautyOptions(call, result);
        break;
      case "getCurrentBeautyOptions":
        getCurrentBeautyOptions(result);
        break;
      case "setBeautyFilter":
        setBeautyFilter(call, result);
        break;
      case "getCurrentBeautyFilter":
        getCurrentBeautyFilter(result);
        break;
      case "resetBeauty":
        resetBeauty(result);
        break;
      default:
        MainThreadPoster.notImplemented(result);
        break;
    }
  }



  private void setBeautyOptions(MethodCall call, Result result) {
    Boolean enable = call.argument("enable");
    assert (enable != null);
    HashMap<String, Object> options = call.argument("options");
    assert (options != null);
    boolean code = RCBeautyIWEngine.getInstance().setBeautyOptions(enable, ArgumentAdapter.toRCBeautyIWOptions(options));
    MainThreadPoster.success(result, code);
  }

  private void getCurrentBeautyOptions(Result result) {
    HashMap<String, Object> options = ArgumentAdapter.fromRCBeautyIWOptions(RCBeautyIWEngine.getInstance().getCurrentBeautyOptions());
    MainThreadPoster.success(result, options);
  }

  private void setBeautyFilter(MethodCall call, Result result) {
    Integer filter = (Integer) call.arguments;
    assert (filter != null);
    boolean code = RCBeautyIWEngine.getInstance().setBeautyFilter(ArgumentAdapter.toRCBeautyIWFilter(filter));
    MainThreadPoster.success(result, code);
  }

  private void getCurrentBeautyFilter(Result result) {
    int filter = RCBeautyIWEngine.getInstance().getCurrentBeautyFilter().ordinal();
    MainThreadPoster.success(result, filter);
  }

  private void resetBeauty(Result result) {
    RCBeautyIWEngine.getInstance().resetBeauty();
    MainThreadPoster.success(result, 0);
  }

  private MethodChannel channel;
}
