import 'package:flutter/services.dart';

import 'package:rongcloud_beauty_wrapper_plugin/wrapper/rongcloud_beauty_constants.dart';
import 'package:rongcloud_beauty_wrapper_plugin/wrapper/rongcloud_beauty_options.dart';

class RCBeautyEngine {

  /// 设置美颜参数
  ///
  /// [enabled] 是否开启美颜 默认关闭
  /// [options] 美颜配置参数
  static Future<bool> setBeautyOptions(bool enable, [RCBeautyOptions options = const RCBeautyOptions.create()]) async {
    Map<String, dynamic> arguments = {
      'enable': enable,
      'options': options.toJson(),
    };
    bool result = await _channel.invokeMethod('setBeautyOptions', arguments);
    return result;
  }

  /// 获取当前美颜参数
  ///
  /// return 当前美颜参数对象
  static Future<RCBeautyOptions> getCurrentBeautyOptions() async {
    Map<String, dynamic> options = await _channel.invokeMethod('getCurrentBeautyOptions');
    return RCBeautyOptions.fromJson(options);
  }

  /// 配置视频滤镜
  ///
  /// [filter] 滤镜类型
  static Future<bool> setBeautyFilter(RCBeautyFilter filter) async {
    bool result = await _channel.invokeMethod('setBeautyFilter', filter.index);
    return result;
  }

  ///  获取当前滤镜参数
  ///
  ///  return 当前滤镜类型
  static Future<RCBeautyFilter> getCurrentBeautyFilter() async {
    int filter = await _channel.invokeMethod('getCurrentBeautyFilter');
    return RCBeautyFilter.values[filter];
  }

  /// 重置美颜的滤镜参数
  ///
  /// 因为底层是单例对象，所以会保留开发者设置的美颜参数或滤镜类型，
  /// 在需要重置美颜的时候（例如重复进入房间时）需要调用 reset 方法重置所有美颜参数和滤镜。
  static Future<int> resetBeauty() async {
    int code = await _channel.invokeMethod('resetBeauty');
    return code;
  }

  static const MethodChannel _channel = MethodChannel('cn.rongcloud.beauty.flutter/engine');
}